#ifndef EL__ECMASCRIPT_MUJS_CONSOLE_H
#define EL__ECMASCRIPT_MUJS_CONSOLE_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

int mjs_console_init(js_State *J);

#ifdef __cplusplus
}
#endif

#endif
